@@ -1,10 +1,11 @@
+from __future__ import with_statement
 from os import path
 from flask import _request_ctx_stack, url_for
 from webassets import Bundle
 from webassets.env import BaseEnvironment, ConfigStorage
 
 
-__version__ = (0, 2, 1)
+__version__ = (0, 2, 2)
 
 __all__ = ('Environment', 'Bundle',)
 
@@ -142,14 +143,33 @@ try:
 except ImportError:
     pass
 else:
+    import argparse
+
+    class CatchAllParser(object):
+        def parse_known_args(self, app_args):
+            return argparse.Namespace(), app_args
+
     class ManageAssets(script.Command):
         """Manage assets."""
+        capture_all_args = True
 
-        def __init__(self, assets_env):
+        def __init__(self, assets_env=None):
             self.env = assets_env
 
-        def handle(self, app, prog, name, remaining_args):
-            from webassets import script
-            return script.main(remaining_args, env=self.env)
+        def create_parser(self, prog):
+            return CatchAllParser()
 
-    __all__ = __all__ + ('ManageAssets',)
\ No newline at end of file
+        def run(self, args):
+            """Runs the management script.
+            If ``self.env`` is not defined, it will import it from
+            ``current_app``.
+            """
+
+            if not self.env:
+                from flask import current_app
+                self.env = current_app.jinja_env.assets_environment
+
+            from webassets import script
+            return script.main(args, env=self.env)
+
+    __all__ = __all__ + ('ManageAssets',)
